# legos-base

legos is a generic asset packaging and management system. It is designed to be flexible, modular, allowing for easy modification of assets and packages.

`legos-base` is a collection of generic base classes which form the foundation of legos framework.
